==> GeneRegionScan_1.8.0.zip: GeneRegionScan/doc/GeneRegionScan.R <==
###################################################
### chunk number 1: gettingProbesets
###################################################
#line 37 "GeneRegionScan.Rnw"
library(GeneRegionScan)


###################################################
### chunk number 2: gettingProbesetsNotRunPart eval=FALSE
###################################################
## #line 41 "GeneRegionScan.Rnw"
## transcriptClustersFile<-"~/HuEx-1-0-st-v2.na26.hg18.transcript.csv"
## mpsToPsFile<-"~/HuEx-1-0-st-v2.r2.dt1.hg18.full.mps"
## listOfProbesets<-getProbesetsFromRegionOfInterest("HuEx-1-0-st-v2", "chr2", 215889955,216106710, transcriptClustersFile=transcriptClustersFile, mpsToPsFile=mpsToPsFile)


###################################################
### chunk number 3: gettingProbeevelSet eval=FALSE
###################################################
## #line 53 "GeneRegionScan.Rnw"
## aptCelExtractPath<-"~/apt-bin/apt-cel-extract"
## clfPath<-"~/HuEx-1-0-st-v2.r2.clf"
## pgfPath<-"~/HuEx-1-0-st-v2.r2.pgf"
## 
## myProbeLevelSet<-getLocalProbeIntensities(listOfProbesets,"~/test-cels", aptCelExtractPath=aptCelExtractPath, pgfPath=pgfPath, clfPath=clfPath)


###################################################
### chunk number 4: getSequence eval=FALSE
###################################################
## #line 67 "GeneRegionScan.Rnw"
## getSequence(myProbeLevelSet,1:5)


###################################################
### chunk number 5: loadData
###################################################
#line 79 "GeneRegionScan.Rnw"
data(exampleProbeLevelSet)
pData(exampleProbeLevelSet)[1:3,]


###################################################
### chunk number 6: plot1
###################################################
#line 88 "GeneRegionScan.Rnw"
plotOnGene(exampleProbeLevelSet, mrna)


###################################################
### chunk number 7: plot2
###################################################
#line 94 "GeneRegionScan.Rnw"
plotOnGene(exampleProbeLevelSet, mrna, summaryType="dots", interval=c(500,1000))


###################################################
### chunk number 8: plot3
###################################################
#line 99 "GeneRegionScan.Rnw"
exonStructure(mrna, genomic)


###################################################
### chunk number 9: plot4
###################################################
#line 107 "GeneRegionScan.Rnw"
plotOnGene(exampleProbeLevelSet, mrna, label="gender", testType="wilcoxon", verbose=FALSE)
exonStructure(mrna, genomic)



###################################################
### chunk number 10: plot5
###################################################
#line 114 "GeneRegionScan.Rnw"
plotOnGene(exampleProbeLevelSet, mrna, label="genotype1", testType="linear model", verbose=FALSE)
exonStructure(mrna, genomic)


###################################################
### chunk number 11: plot5
###################################################
#line 122 "GeneRegionScan.Rnw"
mrna_subset<-mrna
mrna_subset[[1]]$seq<-substr(mrna_subset[[1]]$seq,500,1000)
plotCoexpression(exampleProbeLevelSet, gene=mrna_subset, correlationCutoff=0.5, probeLevelInfo=c("probeid","sequence"), verbose=FALSE)


###################################################
### chunk number 12: plot6 eval=FALSE
###################################################
## #line 129 "GeneRegionScan.Rnw"
## geneRegionScan(exampleProbeLevelSet, gene=mrna, genomicData=genomic, label="genotype3", testType="linear model", correlationCutoff=0.5, probeLevelInfo=c("probeid","sequence"), verbose=FALSE)


###################################################
### chunk number 13: sessioninfo
###################################################
#line 136 "GeneRegionScan.Rnw"

sessionInfo()

==> GeneRegionScan_1.14.0.zip: GeneRegionScan/doc/GeneRegionScan.R <==
### R code from vignette source 'GeneRegionScan.Rnw'

###################################################
### code chunk number 1: gettingProbesets
###################################################
library(GeneRegionScan)


###################################################
### code chunk number 2: gettingProbesetsNotRunPart (eval = FALSE)
###################################################
## transcriptClustersFile<-"~/HuEx-1-0-st-v2.na26.hg18.transcript.csv"
## mpsToPsFile<-"~/HuEx-1-0-st-v2.r2.dt1.hg18.full.mps"
## listOfProbesets<-getProbesetsFromRegionOfInterest("HuEx-1-0-st-v2", "chr2", 215889955,216106710, transcriptClustersFile=transcriptClustersFile, mpsToPsFile=mpsToPsFile)


###################################################
### code chunk number 3: gettingProbeevelSet (eval = FALSE)
###################################################
## aptCelExtractPath<-"~/apt-bin/apt-cel-extract"
## clfPath<-"~/HuEx-1-0-st-v2.r2.clf"
## pgfPath<-"~/HuEx-1-0-st-v2.r2.pgf"
## 
## myProbeLevelSet<-getLocalProbeIntensities(listOfProbesets,"~/test-cels", aptCelExtractPath=aptCelExtractPath, pgfPath=pgfPath, clfPath=clfPath)


###################################################
### code chunk number 4: getSequence (eval = FALSE)
###################################################
## getSequence(myProbeLevelSet,1:5)


###################################################
### code chunk number 5: loadData
###################################################
data(exampleProbeLevelSet)
pData(exampleProbeLevelSet)[1:3,]


###################################################
### code chunk number 6: plot1
###################################################
plotOnGene(exampleProbeLevelSet, mrna)


###################################################
### code chunk number 7: plot2
###################################################
plotOnGene(exampleProbeLevelSet, mrna, summaryType="dots", interval=c(500,1000))
exonStructure(mrna, genomic)


###################################################
### code chunk number 8: plot3
###################################################
plotOnGene(exampleProbeLevelSet, mrna, label="gender", testType="wilcoxon", verbose=FALSE)
exonStructure(mrna, genomic)



###################################################
### code chunk number 9: plot4
###################################################
plotOnGene(exampleProbeLevelSet, mrna, label="genotype1", testType="linear model", verbose=FALSE)
exonStructure(mrna, genomic)


###################################################
### code chunk number 10: plot5
###################################################
mrna_subset<-mrna
mrna_subset[[1]]$seq<-substr(mrna_subset[[1]]$seq,500,1000)
plotCoexpression(exampleProbeLevelSet, gene=mrna_subset, correlationCutoff=0.5, probeLevelInfo=c("probeid","sequence"), verbose=FALSE)


###################################################
### code chunk number 11: plot6 (eval = FALSE)
###################################################
## geneRegionScan(exampleProbeLevelSet, gene=mrna, genomicData=genomic, label="genotype3", testType="linear model", correlationCutoff=0.5, probeLevelInfo=c("probeid","sequence"), verbose=FALSE)


###################################################
### code chunk number 12: sessioninfo
###################################################

sessionInfo()
